@@ -362,7 +362,7 @@ static const short yycheck[] = {     0,
 #define YYPURE 1
 
 /* -*-C-*-  Note some compilers choke on comments on `#line' lines.  */
-#line 3 "/p/share/bison.simple"
+#line 3 "/usr/share/bison/bison.simple"
 /* This file comes from bison-1.28.  */
 
 /* Skeleton output parser for bison,
@@ -576,7 +576,7 @@ __yy_memcpy (char *to, char *from, unsigned int count)
 #endif
 #endif
 
-#line 217 "/p/share/bison.simple"
+#line 217 "/usr/share/bison/bison.simple"
 
 /* The user can define YYPARSE_PARAM as the name of an argument to be passed
    into yyparse.  The argument should have type void *.
@@ -883,14 +883,8 @@ yydefault:
 /* Do a reduction.  yyn is the number of a rule to reduce with.  */
 yyreduce:
   yylen = yyr2[yyn];
-
-  /* If yylen is nonzero, implement the default action `** = *1'.
-     Otherwise, the following line sets `**' to the semantic value of
-     the lookahead token.  This behavior is undocumented and bison
-     users should not rely upon it.  Assigning to yyval
-     unconditionally is a bit faster, and it avoids a GCC warning that
-     yyval may be used uninitialized.  */
-  yyval = yyvsp[1-yylen];
+  if (yylen > 0)
+    yyval = yyvsp[1-yylen]; /* implement default value of the action */
 
 #if YYDEBUG != 0
   if (yydebug)
@@ -1229,7 +1223,7 @@ case 53:
     break;}
 }
    /* the action file gets copied in in place of this dollarsign */
-#line 543 "/p/share/bison.simple"
+#line 543 "/usr/share/bison/bison.simple"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1456,6 +1450,7 @@ yyerrhandle:
    may define-away `const'.  We want the prototype for get_date to have
    the same signature as the function definition.  */
 #include "getdate.h"
+#include "unlocked-io.h"
 
 #ifndef gmtime
 struct tm *gmtime ();
@@ -1998,7 +1993,8 @@ get_date (const char *p, const time_t *now)
 
   /* Let mktime deduce tm_isdst if we have an absolute time stamp,
      or if the relative time stamp mentions days, months, or years.  */
-  if (pc.dates_seen | pc.days_seen | pc.times_seen | pc.rel_day | pc.rel_month | pc.rel_year)
+  if (pc.dates_seen | pc.days_seen | pc.times_seen | pc.rel_day
+      | pc.rel_month | pc.rel_year)
     tm.tm_isdst = -1;
 
   /* But if the input explicitly specifies local time with or without
@@ -2045,6 +2041,7 @@ get_date (const char *p, const time_t *now)
     {
       tm.tm_mday += ((pc.day_number - tm.tm_wday + 7) % 7
 		     + 7 * (pc.day_ordinal - (0 < pc.day_ordinal)));
+      tm.tm_isdst = -1;
       Start = mktime (&tm);
       if (Start == (time_t) -1)
 	return Start;
