@@ -1,5 +1,5 @@
 /* linebuffer.c -- read arbitrarily long lines
-   Copyright (C) 1986, 1991, 1998, 1999 Free Software Foundation, Inc.
+   Copyright (C) 1986, 1991, 1998, 1999, 2001 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <stdio.h>
 #include <sys/types.h>
 #include "linebuffer.h"
+#include "unlocked-io.h"
 
 char *xmalloc ();
 char *xrealloc ();
@@ -41,8 +42,7 @@ initbuffer (struct linebuffer *linebuffer)
 
 /* Read an arbitrarily long line of text from STREAM into LINEBUFFER.
    Keep the newline; append a newline if it's the last line of a file
-   that ends in a non-newline character.  Do not null terminate,
-   but leave room for an extra byte after the newline.
+   that ends in a non-newline character.  Do not null terminate.
    Return LINEBUFFER, except at end of file return 0.  */
 
 struct linebuffer *
@@ -51,7 +51,7 @@ readline (struct linebuffer *linebuffer, FILE *stream)
   int c;
   char *buffer = linebuffer->buffer;
   char *p = linebuffer->buffer;
-  char *end = buffer + linebuffer->size - 1; /* Sentinel. */
+  char *end = buffer + linebuffer->size; /* Sentinel. */
 
   if (feof (stream) || ferror (stream))
     return 0;
@@ -73,7 +73,7 @@ readline (struct linebuffer *linebuffer, FILE *stream)
 	  buffer = (char *) xrealloc (buffer, linebuffer->size);
 	  p = p - linebuffer->buffer + buffer;
 	  linebuffer->buffer = buffer;
-	  end = buffer + linebuffer->size - 1;
+	  end = buffer + linebuffer->size;
 	}
       *p++ = c;
     }
