@@ -1,5 +1,5 @@
 /* csplit - split a file into sections determined by context lines
-   Copyright (C) 91, 1995-2000 Free Software Foundation, Inc.
+   Copyright (C) 91, 1995-2001 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 #include <config.h>
 
 #include <stdio.h>
-#include <assert.h>
 #include <getopt.h>
 #include <sys/types.h>
 #include <signal.h>
@@ -769,12 +768,6 @@ process_line_count (const struct control *p, int repetition)
 
   linenum = get_first_line_in_buffer ();
 
-  /* Initially, I wanted to assert linenum < last_line_to_save, but that
-     condition is false for the valid command: echo | csplit - 1 '{*}'.
-     So, relax it just a little.  */
-  assert ((linenum == 1 && last_line_to_save == 1)
-	  || linenum < last_line_to_save);
-
   while (linenum++ < last_line_to_save)
     {
       line = remove_line ();
@@ -1503,13 +1496,16 @@ usage (int status)
 Usage: %s [OPTION]... FILE PATTERN...\n\
 "),
 	      program_name);
-      printf (_("\
+      fputs (_("\
 Output pieces of FILE separated by PATTERN(s) to files `xx01', `xx02', ...,\n\
 and output byte counts of each piece to standard output.\n\
 \n\
-  -b, --suffix-format=FORMAT use sprintf FORMAT instead of %%d\n\
+Mandatory arguments to long options are mandatory for short options too.\n\
+  -b, --suffix-format=FORMAT use sprintf FORMAT instead of %d\n\
   -f, --prefix=PREFIX        use PREFIX instead of `xx'\n\
   -k, --keep-files           do not remove output files on errors\n\
+"), stdout);
+      fputs (_("\
   -n, --digits=DIGITS        use specified number of digits instead of 2\n\
   -s, --quiet, --silent      do not print counts of output file sizes\n\
   -z, --elide-empty-files    remove empty output files\n\
@@ -1517,15 +1513,17 @@ and output byte counts of each piece to standard output.\n\
       --version              output version information and exit\n\
 \n\
 Read standard input if FILE is -.  Each PATTERN may be:\n\
+"), stdout);
+      fputs (_("\
 \n\
   INTEGER            copy up to but not including specified line number\n\
   /REGEXP/[OFFSET]   copy up to but not including a matching line\n\
-  %%REGEXP%%[OFFSET]   skip to, but not including a matching line\n\
+  %REGEXP%[OFFSET]   skip to, but not including a matching line\n\
   {INTEGER}          repeat the previous pattern specified number of times\n\
   {*}                repeat the previous pattern as many times as possible\n\
 \n\
 A line OFFSET is a required `+' or `-' followed by a positive integer.\n\
-"));
+"), stdout);
       puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
     }
   exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
