@@ -50,7 +50,7 @@ struct rlimit { size_t rlim_cur; };
 /* The official name of this program (e.g., no `g' prefix).  */
 #define PROGRAM_NAME "sort"
 
-#define AUTHORS "Mike Haertel and Paul Eggert"
+#define AUTHORS N_ ("Mike Haertel and Paul Eggert")
 
 #if defined ENABLE_NLS && HAVE_LANGINFO_H
 # include <langinfo.h>
@@ -286,23 +286,25 @@ usage (int status)
 Usage: %s [OPTION]... [FILE]...\n\
 "),
 	      program_name);
-      printf (_("\
+      fputs (_("\
 Write sorted concatenation of all FILE(s) to standard output.\n\
 \n\
 Ordering options:\n\
 \n\
+Mandatory arguments to long options are mandatory for short options too.\n\
   -b, --ignore-leading-blanks ignore leading blanks\n\
   -d, --dictionary-order      consider only blanks and alphanumeric characters\n\
   -f, --ignore-case           fold lower case to upper case characters\n\
+"), stdout);
+      fputs (_("\
   -g, --general-numeric-sort  compare according to general numerical value\n\
   -i, --ignore-nonprinting    consider only printable characters\n\
   -M, --month-sort            compare (unknown) < `JAN' < ... < `DEC'\n\
   -n, --numeric-sort          compare according to string numerical value\n\
   -r, --reverse               reverse the result of comparisons\n\
 \n\
-")
-	      );
-      printf (_("\
+"), stdout);
+      fputs (_("\
 Other options:\n\
 \n\
   -c, --check               check whether input is sorted; do not sort\n\
@@ -311,20 +313,23 @@ Other options:\n\
   -o, --output=FILE         write result to FILE instead of standard output\n\
   -s, --stable              stabilize sort by disabling last-resort comparison\n\
   -S, --buffer-size=SIZE    use SIZE for main memory buffer\n\
+"), stdout);
+      printf (_("\
   -t, --field-separator=SEP use SEP instead of non- to whitespace transition\n\
   -T, --temporary-directory=DIR  use DIR for temporaries, not $TMPDIR or %s\n\
                               multiple options specify multiple directories\n\
   -u, --unique              with -c: check for strict ordering\n\
                               otherwise: output only the first of an equal run\n\
+"), DEFAULT_TMPDIR);
+      fputs (_("\
   -z, --zero-terminated     end lines with 0 byte, not newline\n\
   +POS1 [-POS2]             start a key at POS1, end it before POS2 (origin 0)\n\
                               Warning: this option is obsolescent\n\
       --help       display this help and exit\n\
       --version    output version information and exit\n\
 \n\
-"),
-	      DEFAULT_TMPDIR);
-      printf (_("\
+"), stdout);
+      fputs (_("\
 POS is F[.C][OPTS], where F is the field number and C the character position\n\
 in the field, both counted from one with -k, from zero with the obsolescent\n\
 form.  OPTS is made up of one or more single-letter ordering options, which\n\
@@ -332,15 +337,17 @@ override global ordering options for that key.  If no key is given, use the\n\
 entire line as the key.\n\
 \n\
 SIZE may be followed by the following multiplicative suffixes:\n\
-%% 1%% of memory, b 1, k 1024 (default), and so on for M, G, T, P, E, Z, Y.\n\
+"), stdout);
+      fputs (_("\
+% 1% of memory, b 1, k 1024 (default), and so on for M, G, T, P, E, Z, Y.\n\
 \n\
 With no FILE, or when FILE is -, read standard input.\n\
 \n\
 *** WARNING ***\n\
 The locale specified by the environment affects sort order.\n\
-Set LC_ALL=C to get the traditional sort order that uses native byte values.\n\
-")
-	      );
+Set LC_ALL=C to get the traditional sort order that uses\n\
+native byte values.\n\
+"), stdout );
       puts (_("\nReport bugs to <bug-textutils@gnu.org>."));
     }
   /* Don't use EXIT_FAILURE here in case it is defined to be 1.
@@ -527,7 +534,7 @@ zaptemp (const char *name)
       }
 }
 
-#ifdef ENABLE_NLS
+#if defined ENABLE_NLS && HAVE_NL_LANGINFO
 
 static int
 struct_month_cmp (const void *m1, const void *m2)
@@ -536,7 +543,7 @@ struct_month_cmp (const void *m1, const void *m2)
 		 ((const struct month *) m2)->name);
 }
 
-#endif /* NLS */
+#endif
 
 /* Initialize the character class tables. */
 
@@ -1641,7 +1648,7 @@ mergefps (char **files, register int nfiles,
     {
       fps[i] = xfopen (files[i], "r");
       initbuf (&buffer[i], sizeof (struct line),
-	       MAX (merge_buffer_size, sort_size));
+	       MAX (merge_buffer_size, sort_size / nfiles));
       /* If a file is empty, eliminate it from future consideration. */
       while (i < nfiles && !fillbuf (&buffer[i], fps[i], files[i]))
 	{
