@@ -141,7 +141,11 @@
 # define RETSIGTYPE void
 #endif
 
-#ifndef __GNUC__
+#if __GNUC__
+# ifndef alloca
+#  define alloca __builtin_alloca
+# endif
+#else
 # if HAVE_ALLOCA_H
 #  include <alloca.h>
 # else
@@ -360,65 +364,8 @@ uid_t getuid ();
 # define mempcpy(D, S, N) ((void *) ((char *) memcpy (D, S, N) + (N)))
 #endif
 
-/* These are wrappers for functions/macros from GNU libc.
-   The standard I/O functions are thread-safe.  These *_unlocked ones
-   are more efficient but not thread-safe.  That they're not thread-safe
-   is fine since all these applications are single threaded.  */
-
-#if HAVE_CLEARERR_UNLOCKED
-# undef clearerr
-# define clearerr(S) clearerr_unlocked (S)
-#endif
-
-#if HAVE_FEOF_UNLOCKED
-# undef feof
-# define feof(S) feof_unlocked (S)
-#endif
-
-#if HAVE_FERROR_UNLOCKED
-# undef ferror
-# define ferror(S) ferror_unlocked (S)
-#endif
-
-#if HAVE_FFLUSH_UNLOCKED
-# undef fflush
-# define fflush(S) fflush_unlocked (S)
-#endif
-
-#if HAVE_FPUTC_UNLOCKED
-# undef fputc
-# define fputc(C, S) fputc_unlocked (C, S)
-#endif
-
-#if HAVE_FREAD_UNLOCKED
-# undef fread
-# define fread(P, Z, N, S) fread_unlocked (P, Z, N, S)
-#endif
-
-#if HAVE_FWRITE_UNLOCKED
-# undef fwrite
-# define fwrite(P, Z, N, S) fwrite_unlocked (P, Z, N, S)
-#endif
-
-#if HAVE_GETC_UNLOCKED
-# undef getc
-# define getc(S) getc_unlocked (S)
-#endif
-
-#if HAVE_GETCHAR_UNLOCKED
-# undef getchar
-# define getchar(S) getchar_unlocked (S)
-#endif
-
-#if HAVE_PUTC_UNLOCKED
-# undef putc
-# define putc(C, S) putc_unlocked (C, S)
-#endif
-
-#if HAVE_PUTCHAR_UNLOCKED
-# undef putchar
-# define putchar(C) putchar_unlocked (C)
-#endif
+/* Include automatically-generated macros for unlocked I/O.  */
+#include "unlocked-io.h"
 
 #define SAME_INODE(Stat_buf_1, Stat_buf_2) \
   ((Stat_buf_1).st_ino == (Stat_buf_2).st_ino \
@@ -436,8 +383,6 @@ uid_t getuid ();
     setvbuf (Stream, Buffer, Type, Size)
 #endif
 
-char *base_name PARAMS ((char const *));
-
 /* Factor out some of the common --help and --version processing code.  */
 
 /* These enum values cannot possibly conflict with the option values
@@ -488,6 +433,11 @@ enum
 			      ? ~ (t) 0 << (sizeof (t) * CHAR_BIT - 1) : (t) 0))
 #define TYPE_MAXIMUM(t) ((t) (~ (t) 0 - TYPE_MINIMUM (t)))
 
+/* Upper bound on the string length of an integer converted to string.
+   302 / 1000 is ceil (log10 (2.0)).  Subtract 1 for the sign bit;
+   add 1 for integer division truncation; add 1 more for a minus sign.  */
+#define INT_STRLEN_BOUND(t) ((sizeof (t) * CHAR_BIT - 1) * 302 / 1000 + 2)
+
 #ifndef CHAR_MIN
 # define CHAR_MIN TYPE_MINIMUM (char)
 #endif
